fn get_target_file_name(target_name: &str) -> &'static str
Converts the given target name into the appropriate input file name based on the targets defined in debugger_tester.common.Target
debugger_tester.common.Target